<?php

declare(strict_types=1);

namespace Apexl\Io\Jobs\Requests;

use Apexl\Io\Requests\IoRequest;

class QueueProcessRequest extends IoRequest
{
    public function limit(): ?int
    {
        return $this->bodyParam('limit');
    }
}
