<?php

declare(strict_types=1);

namespace Apexl\Io\Jobs\Dtos;

/** What one handler has sitting in `job_queue`. */
final readonly class QueueHandlerSummary
{
    public function __construct(
        public string $handler,
        public int $queued,
        public int $failed,
        public int $deferred,
        public int $locked,
    ) {}
}
