<?php

declare(strict_types=1);

use Apexl\Io\Jobs\Interfaces\QueuedTaskFinderInterface;
use Apexl\Io\Jobs\Services\QueuedTaskFinderDb;
use function DI\autowire;

return [
    QueuedTaskFinderInterface::class => autowire(QueuedTaskFinderDb::class),
];
